@@ -16,11 +16,8 @@ def Authenticate(_Authorization_Token):
     if _Authorization_Token:
         token_length = len(_Authorization_Token)
         if token_length < 27:
-            raise UrlcutError("Error")
+            raise UrlcutError("API key is too short to be valid.")
         else:
             Token = _Authorization_Token
     else:
-        raise UrlcutError("No API key provided.")
-
-Authenticate("PCEnv5-POrz4K-OUY8ZR-dgsf5J")
-
+        raise UrlcutError("No API key provided.")
\ No newline at end of file
